#
# spec file for package python-jupyter_qgrid
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with     test
Name:           python-jupyter_qgrid
Version:        1.1.1
Release:        lp151.1.1
Summary:        Grid for sorting and filtering DataFrames in Jupyter notebooks
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/quantopian/qgrid
Source:         https://files.pythonhosted.org/packages/source/q/qgrid/qgrid-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-jupyter_ipywidgets >= 7.0.0
BuildRequires:  python3-jupyter_notebook >= 4.0.0
BuildRequires:  python3-pandas >= 0.18.0
%if %{with test}
BuildRequires:  %{python_module jupyter_ipywidgets >= 7.0.0}
BuildRequires:  %{python_module jupyter_notebook >= 4.0.0}
BuildRequires:  %{python_module pandas >= 0.18.0}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-jupyter_ipywidgets >= 7.0.0
Requires:       python-jupyter_notebook >= 4.0.0
Requires:       python-pandas >= 0.18.0
Provides:       python-qgrid = %{version}
Obsoletes:      python-qgrid < %{version}
%ifpython3
Requires(post):   python-jupyter_ipywidgets >= 7.0.0
Requires(post):   python-jupyter_notebook >= 4.0.0
Requires(post):   python-pandas >= 0.18.0
Requires(preun):  python-jupyter_ipywidgets >= 7.0.0
Requires(preun):  python-jupyter_notebook >= 4.0.0
Requires(preun):  python-pandas >= 0.18.0
%endif
%ifpython2
Requires:       python3-jupyter_qgrid = %{version}
%endif
BuildArch:      noarch

%python_subpackages

%description
An Interactive Grid for Sorting and Filtering DataFrames in Jupyter Notebook.

%prep
%setup -q -n qgrid-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_datadir}/jupyter/nbextensions/
%{python_expand $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/qgrid/tests/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/qgrid/tests/
}
%python_expand %fdupes %{buildroot}%{$python_sitelib}/qgrid/tests/

%post -n python3-jupyter_qgrid
jupyter nbextension enable --system --py qgrid || true

%preun -n python3-jupyter_qgrid
if [ $1 = 0 ] && [ -d %{python3_sitelib}/qgrid/ ] ; then
    jupyter nbextension disable --system --py qgrid || true
fi

%if %{with test}
%check
export PYTHONDONTWRITEBYTECODE=1
%python_expand py.test-%{$python_bin_suffix} qgrid
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%{python_sitelib}/qgrid/
%{python_sitelib}/qgrid-%{version}-py*.egg-info
%python3_only %{_datadir}/jupyter/nbextensions/qgrid/

%changelog
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 1.1.1
  * Fixes an issue where the grid widget would flash noticeably
    when the df attribute or any other attributes were changed.
    This issue has existed since 1.0. (#186)
  * Make the SlickGrid object available via
    $('.q-grid').data('slickgrid') as suggested here:
    [#178] (comment). This allows you to work with a particular
    SlickGrid instance from the js console.
- Update to 1.1.0
  * Column options can be provided via the show_grid method.
    Options can be provided for all columns via the
    column_options parameter, and for individual columns via the
    column_definitions parameter.
  * Added edit_cell, change_selection, toggle_editable methods
    for updating the state of an existing grid widget without
    having to call show_grid.
  * Updated the add_row method so that the caller can specify
    the values for the new row via the row parameter. This will
    allow people to add rows to a qgrid instance even if it's
    showing a DataFrame that doesn't have an integer index.
  * Updated the remove_row method so that the indices of the rows
    to remove can optionally be provided via the rows parameter.
  * Fixed issue where moving the scroll bar around a bunch of
    times quickly can cause a series of grid refreshes to occur.
  * Thanks to Abigail Hahn (vardaofthevalier) for adding many of
    the features in the following PR: #191
* Sun Jun 10 2018 jengelh@inai.de
- Avoid bashism in scriptlet.
* Thu Jun  7 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu Jun  7 2018 toddrme2178@gmail.com
- Update to 1.0.5
  * Fixes issue where editing cells in a DataFrame with an unnamed
    index results in an error pop up
  * Make categorical column filtering work with old versions of
    pandas, like 0.18
  * Adds new on and off methods at both the module-level (for
    listening to events on all qgrid instances) and at the
    instance-level (for listening to events on individual qgrid
    instances)
  * The on and off methods mentioned above should now be used to
    listen for events instead of listening for the on_value_change
    event of the _df attribute. In other words using
    qgrid_widget.observe(on_value_change, names=['_df']) for being
    notified about changes to the state of the grid (i.e. editing,
    sorting, filtering) will no longer work.
- Use || true syntax instead of exit 0
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to 1.0.2
  * Fixes issue that made it impossible to set the value of a float cell to zero #174
  * Updated tests to be python 2 compatible by removing usages of nonlocal. This change will help us to simplify the coda build process.
* Thu Feb 15 2018 toddrme2178@gmail.com
- Update to 1.0.1b1
  * Fix handling of grid_options in set_defaults
* Wed May  6 2015 toddrme2178@gmail.com
- Initial version
